@@ -1466,12 +1466,13 @@ aicc.cpmSize <- function(x, ... ){
 desc <- function(model_CP, Ir = c(1, 3, 7, 14, 28), CL = 0.9, nsim = 10000){
   if (!"cpm" %in% class(model_CP)) stop("model_CP must be a cpm object.")
   # set up summary table
+  Ir <- sort(Ir)
   t0 <- numeric(length(Ir))
   t1 <- Ir
   tf <- t1
   Irv <- paste0("r", Ir)
   cell_desc <- matrix(nrow = model_CP$ncell, ncol = 1 + 3 * (5 + length(Ir)))
-  Irvec <- gtools::mixedsort(c(Irv, paste0(Irv, "_lwr"), paste0(Irv, "_upr")))
+  Irvec <- c(Irv, paste0(Irv, "_lwr"), paste0(Irv, "_upr"))
   colnames(cell_desc) <- c("n", "medianCP", "CP_lwr", "CP_upr", Irvec,
     paste0("pda_", c("median", "lwr", "upr")), paste0("pdb_", c("median", "lwr", "upr")),
     paste0("l_", c("median", "lwr", "upr")), paste0("s_", c("median", "lwr", "upr")))
@@ -1504,7 +1505,7 @@ desc <- function(model_CP, Ir = c(1, 3, 7, 14, 28), CL = 0.9, nsim = 10000){
   rsum <- lapply(rstat, function(xx)
     matrixStats::rowQuantiles(xx, probs = ci_lu))
   for (ci in rownames(cell_desc)){
-    cell_desc[ci, gtools::mixedsort(c(paste0(Irv, "_lwr"), paste0(Irv, "_upr")))]  <-
+    cell_desc[ci, c(paste0(Irv, "_lwr"), paste0(Irv, "_upr"))]  <-
       t(rsum[[ci]])
   }
   # calculate cp statistics
